@@ -296,7 +296,7 @@ class AlchemyJsonApiViewBuilder:
                 attributes = self._before_update_callback(request, attributes, obj)
 
             for field in self._fields:
-                if field != identifier:
+                if field != identifier and field in attributes:
                     setattr(obj, field, attributes[field])
 
             obj.save()
